@@ -4,11 +4,15 @@
  *	pqxx/tablestream.h
  *
  *   DESCRIPTION
- *      definition of the pqxx::TableStream class.
- *   pqxx::TableStream provides optimized batch access to a database table
+ *      definition of the pqxx::tablestream class.
+ *   pqxx::tablestream provides optimized batch access to a database table
  *
  * Copyright (c) 2001-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
+ * See COPYING for copyright license.  If you did not receive a file called
+ * COPYING with this source code, please notify the distributor of this mistake,
+ * or contact the author.
+ *
  *-------------------------------------------------------------------------
  */
 #ifndef PQXX_TABLESTREAM_H
@@ -27,43 +31,45 @@ namespace pqxx
 
 // TODO: Non-blocking access to help hide network latencies
 
-class Transaction_base;
+class transaction_base;
 
 
 /// Base class for streaming data to/from database tables.
 /** A Tablestream enables optimized batch read or write access to a database 
  * table using PostgreSQL's COPY TO STDOUT and COPY FROM STDIN commands,
  * respectively.  These capabilities are implemented by its subclasses 
- * TableReader and TableWriter.
+ * tablereader and tablewriter.
  * A Tablestream exists in the context of a transaction, and no other streams
  * or queries may be applied to that transaction as long as the stream remains
  * open.
  */
-class PQXX_LIBEXPORT TableStream
+class PQXX_LIBEXPORT tablestream
 {
 public:
-  TableStream(Transaction_base &Trans, 
+  tablestream(transaction_base &Trans, 
 	      const PGSTD::string &Name, 
 	      const PGSTD::string &Null=PGSTD::string());			//[t6]
-  virtual ~TableStream() =0;						//[t6]
+  virtual ~tablestream() =0;						//[t6]
 
   PGSTD::string Name() const { return m_Name; }				//[t10]
 
 protected:
-  Transaction_base &Trans() const throw () { return m_Trans; }
+  transaction_base &Trans() const throw () { return m_Trans; }
   PGSTD::string NullStr() const { return m_Null; }
 
 private:
-  Transaction_base &m_Trans;
+  transaction_base &m_Trans;
   PGSTD::string m_Name;
   PGSTD::string m_Null;
 
   // Not allowed:
-  TableStream();
-  TableStream(const TableStream &);
-  TableStream &operator=(const TableStream &);
+  tablestream();
+  tablestream(const tablestream &);
+  tablestream &operator=(const tablestream &);
 };
 
+/// @deprecated For compatibility with the old TableStream class
+typedef tablestream TableStream;
 
 }
 
