@@ -4,29 +4,33 @@
  *	pqxx/transaction.h
  *
  *   DESCRIPTION
- *      definition of the pqxx::Transaction class.
- *   pqxx::Transaction represents a database transaction
+ *      definition of the pqxx::transaction class.
+ *   pqxx::transaction represents a database transaction
  *
  * Copyright (c) 2001-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
+ * See COPYING for copyright license.  If you did not receive a file called
+ * COPYING with this source code, please notify the distributor of this mistake,
+ * or contact the author.
+ *
  *-------------------------------------------------------------------------
  */
 #ifndef PQXX_TRANSACTION_H
 #define PQXX_TRANSACTION_H
 
-/* While you may choose to create your own Transaction object to interface to 
+/* While you may choose to create your own transaction object to interface to 
  * the database backend, it is recommended that you wrap your transaction code 
- * into a Transactor code instead and let the Transaction be created for you.
- * See pqxx/transactor.h for more about Transactor.
+ * into a transactor code instead and let the transaction be created for you.
+ * See pqxx/transactor.h for more about transactor.
  *
- * If you should find that using a Transactor makes your code less portable or 
- * too complex, go ahead, create your own Transaction anyway.
+ * If you should find that using a transactor makes your code less portable or 
+ * too complex, go ahead, create your own transaction anyway.
  */
 
 // Usage example: double all wages
 //
-// extern Connection C;
-// Transaction T(C);
+// extern connection C;
+// transaction<> T(C);
 // try
 // {
 //   T.Exec("UPDATE employees SET wage=wage*2");
@@ -38,8 +42,7 @@
 //   T.Abort();		// Usually not needed; same happens when T's life ends.
 // }
 
-#include "pqxx/connection_base.h"
-#include "pqxx/transaction_base.h"
+#include "pqxx/dbtransaction.h"
 
 /* Methods tested in eg. self-test program test1 are marked with "//[t1]"
  */
@@ -50,20 +53,44 @@
 namespace pqxx
 {
 
-/// Back-end transaction.
-/** Use a Transaction object to enclose operations on a database in a single
+class PQXX_LIBEXPORT basic_transaction : public dbtransaction
+{
+protected:
+  explicit basic_transaction(connection_base &C, 
+			     const PGSTD::string &IsolationLevel,
+			     const PGSTD::string &TName) :		//[t1]
+    dbtransaction(C, IsolationLevel, TName) {}
+
+private:
+  virtual void DoBegin();						//[t1]
+  virtual result DoExec(const char[]);					//[t1]
+  virtual void DoCommit();						//[t1]
+  virtual void DoAbort();						//[t13]
+
+};
+
+
+/// Human-readable class name for use by unique
+template<> inline PGSTD::string Classname(const basic_transaction *) 
+{ 
+  return "basic_transaction"; 
+}
+
+
+/// Standard back-end transaction, templatized on isolation level
+/** Use a transaction object to enclose operations on a database in a single
  * "unit of work."  This ensures that the whole series of operations either
  * succeeds as a whole or fails completely.  In no case will it leave half
  * finished work behind in the database.
  *
- * Queries can currently only be issued through a Transaction.
+ * Queries can currently only be issued through a transaction.
  *
  * Once processing on a transaction has succeeded and any changes should be
  * allowed to become permanent in the database, call Commit().  If something
  * has gone wrong and the changes should be forgotten, call Abort() instead.
  * If you do neither, an implicit Abort() is executed at destruction time.
  *
- * It is an error to abort a Transaction that has already been committed, or to 
+ * It is an error to abort a transaction that has already been committed, or to 
  * commit a transaction that has already been aborted.  Aborting an already 
  * aborted transaction or committing an already committed one has been allowed 
  * to make errors easier to deal with.  Repeated aborts or commits have no
@@ -75,23 +102,34 @@ namespace pqxx
  * this since application-specific considerations become important at this 
  * point.
  */
-class PQXX_LIBEXPORT Transaction : public Transaction_base
+template<isolation_level ISOLATIONLEVEL=read_committed>
+class PQXX_LIBEXPORT transaction : public basic_transaction
 {
 public:
+  typedef isolation_traits<ISOLATIONLEVEL> isolation_tag;
+
   /// Create a transaction.  The optional name, if given, must begin with a
   /// letter and may contain letters and digits only.
-  explicit Transaction(Connection_base &, 
-		       const PGSTD::string &Name=PGSTD::string());	//[t1]
+  explicit transaction(connection_base &C,
+		       const PGSTD::string &TName=PGSTD::string()) :	//[]
+    basic_transaction(C, isolation_tag::name(), TName) 
+    	{ Begin(); }
 
-  virtual ~Transaction();						//[t1]
-
-private:
-  virtual void DoBegin();						//[t1]
-  virtual Result DoExec(const char[]);					//[t1]
-  virtual void DoCommit();						//[t1]
-  virtual void DoAbort();						//[t13]
+  virtual ~transaction() { End(); }
 };
 
+
+/// Human-readable class names for use by unique template.
+template<isolation_level ISOLATIONLEVEL> 
+inline PGSTD::string Classname(const transaction<ISOLATIONLEVEL> *) 
+{ 
+  return "transaction<" + isolation_traits<ISOLATIONLEVEL>::name() + ">";
+}
+
+
+/// @deprecated Compatibility with the old Transaction class
+typedef transaction<read_committed> Transaction;
+
 }
 
 #endif
