@@ -8,6 +8,10 @@
  *
  * Copyright (c) 2001-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
+ * See COPYING for copyright license.  If you did not receive a file called
+ * COPYING with this source code, please notify the distributor of this mistake,
+ * or contact the author.
+ *
  *-------------------------------------------------------------------------
  */
 #ifndef PQXX_UTIL_H
@@ -28,8 +32,15 @@ extern "C"
 
 namespace pqxx
 {
-typedef long Result_size_type;
-typedef int Tuple_size_type;
+typedef long result_size_type;
+typedef int tuple_size_type;
+
+/// PostgreSQL row identifier type
+typedef Oid oid;
+
+/// The "null" oid
+const oid oid_none = InvalidOid;
+
 
 /// C-style format strings for various built-in types.  Only allowed for
 /// certain types, for which this function is explicitly specialized below.
@@ -67,6 +78,8 @@ template<typename T> inline PGSTD::string ToString(const T &Obj)
   return PGSTD::string(Buf);
 }
 
+// TODO: Implement date conversions
+
 template<> inline PGSTD::string ToString(const PGSTD::string &Obj) {return Obj;}
 template<> inline PGSTD::string ToString(const char *const &Obj) { return Obj; }
 template<> inline PGSTD::string ToString(char *const &Obj) { return Obj; }
@@ -334,10 +347,10 @@ private:
 /// for the guest type, and that GUEST::Name() returns a user-readable name for
 /// the GUEST object.
 template<typename GUEST>
-class PQXX_LIBEXPORT Unique
+class PQXX_LIBEXPORT unique
 {
 public:
-  Unique() : m_Guest(0) {}
+  unique() : m_Guest(0) {}
 
   GUEST *get() const throw () { return m_Guest; }
 
@@ -395,8 +408,8 @@ private:
   GUEST *m_Guest;
 
   // Not allowed:
-  Unique(const Unique &);
-  Unique &operator=(const Unique &);
+  unique(const unique &);
+  unique &operator=(const unique &);
 };
 
 }
