@@ -4,11 +4,15 @@
  *	nontransaction.cxx
  *
  *   DESCRIPTION
- *      implementation of the pqxx::NonTransaction class.
- *   pqxx::Transaction provides nontransactional database access
+ *      implementation of the pqxx::nontransaction class.
+ *   pqxx::nontransaction provides nontransactional database access
  *
  * Copyright (c) 2002-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
+ * See COPYING for copyright license.  If you did not receive a file called
+ * COPYING with this source code, please notify the distributor of this mistake,
+ * or contact the author.
+ *
  *-------------------------------------------------------------------------
  */
 
@@ -17,13 +21,13 @@
 
 using namespace PGSTD;
 
-pqxx::NonTransaction::~NonTransaction()
+pqxx::nontransaction::~nontransaction()
 {
   End();
 }
 
 
-pqxx::Result pqxx::NonTransaction::DoExec(const char Query[])
+pqxx::result pqxx::nontransaction::DoExec(const char Query[])
 {
   return DirectExec(Query, 2, 0);
 }
