@@ -4,11 +4,15 @@
  *	result.cxx
  *
  *   DESCRIPTION
- *      implementation of the pqxx::Result class and support classes.
- *   pqxx::Result represents the set of result tuples from a database query
+ *      implementation of the pqxx::result class and support classes.
+ *   pqxx::result represents the set of result tuples from a database query
  *
  * Copyright (c) 2001-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
+ * See COPYING for copyright license.  If you did not receive a file called
+ * COPYING with this source code, please notify the distributor of this mistake,
+ * or contact the author.
+ *
  *-------------------------------------------------------------------------
  */
 #include <new>
@@ -21,7 +25,7 @@
 using namespace PGSTD;
 
 
-pqxx::Result &pqxx::Result::operator=(const pqxx::Result &Other)
+pqxx::result &pqxx::result::operator=(const pqxx::result &Other)
 {
   if (Other.m_Result != m_Result)
   {
@@ -32,7 +36,7 @@ pqxx::Result &pqxx::Result::operator=(const pqxx::Result &Other)
 }
 
 
-pqxx::Result &pqxx::Result::operator=(PGresult *Other)
+pqxx::result &pqxx::result::operator=(PGresult *Other)
 {
   if (Other != m_Result)
   {
@@ -44,7 +48,7 @@ pqxx::Result &pqxx::Result::operator=(PGresult *Other)
 
 
 
-const pqxx::Result::Tuple pqxx::Result::at(pqxx::Result::size_type i) const
+const pqxx::result::tuple pqxx::result::at(pqxx::result::size_type i) const
 {
   if ((i < 0) || (i >= size()))
     throw out_of_range("Tuple number out of range");
@@ -53,7 +57,7 @@ const pqxx::Result::Tuple pqxx::Result::at(pqxx::Result::size_type i) const
 }
 
 
-void pqxx::Result::CheckStatus(const string &Query) const
+void pqxx::result::CheckStatus(const string &Query) const
 {
   if (!m_Result)
     throw runtime_error("No result");
@@ -76,13 +80,13 @@ void pqxx::Result::CheckStatus(const string &Query) const
 
   default:
     throw logic_error("Internal libpqxx error: "
-		      "pqxx::Result: Unrecognized response code " +
+		      "pqxx::result: Unrecognized response code " +
 		      ToString(int(PQresultStatus(m_Result))));
   }
 }
 
 
-void pqxx::Result::MakeRef(PGresult *Other)
+void pqxx::result::MakeRef(PGresult *Other)
 {
   if (Other)
   {
@@ -100,7 +104,7 @@ void pqxx::Result::MakeRef(PGresult *Other)
 }
 
 
-void pqxx::Result::MakeRef(const pqxx::Result &Other)
+void pqxx::result::MakeRef(const pqxx::result &Other)
 {
   m_Result = Other.m_Result;
   m_Refcount = Other.m_Refcount;
@@ -109,7 +113,7 @@ void pqxx::Result::MakeRef(const pqxx::Result &Other)
 }
 
 
-void pqxx::Result::LoseRef() throw ()
+void pqxx::result::LoseRef() throw ()
 {
   if (m_Refcount)
   {
@@ -130,54 +134,54 @@ void pqxx::Result::LoseRef() throw ()
 
 
 
-pqxx::Result::size_type pqxx::Result::AffectedRows() const
+pqxx::result::size_type pqxx::result::AffectedRows() const
 {
   const char *const RowsStr = PQcmdTuples(m_Result);
   return RowsStr[0] ? atoi(RowsStr) : 0;
 }
 
 
-const char *pqxx::Result::GetValue(pqxx::Result::size_type Row, 
-		                 pqxx::Result::Tuple::size_type Col) const
+const char *pqxx::result::GetValue(pqxx::result::size_type Row, 
+		                 pqxx::result::tuple::size_type Col) const
 {
   return PQgetvalue(m_Result, Row, Col);
 }
 
 
-bool pqxx::Result::GetIsNull(pqxx::Result::size_type Row,
-		           pqxx::Result::Tuple::size_type Col) const
+bool pqxx::result::GetIsNull(pqxx::result::size_type Row,
+		           pqxx::result::tuple::size_type Col) const
 {
   return PQgetisnull(m_Result, Row, Col) != 0;
 }
 
-pqxx::Result::Field::size_type 
-pqxx::Result::GetLength(pqxx::Result::size_type Row,
-                        pqxx::Result::Tuple::size_type Col) const
+pqxx::result::field::size_type 
+pqxx::result::GetLength(pqxx::result::size_type Row,
+                        pqxx::result::tuple::size_type Col) const
 {
   return PQgetlength(m_Result, Row, Col);
 }
 
 
 
-// Tuple
+// tuple
 
-pqxx::Result::Field pqxx::Result::Tuple::operator[](const char f[]) const
+pqxx::result::field pqxx::result::tuple::operator[](const char f[]) const
 {
-  return Field(*this, m_Home->ColumnNumber(f));
+  return field(*this, m_Home->ColumnNumber(f));
 }
 
 
-pqxx::Result::Field pqxx::Result::Tuple::at(const char f[]) const
+pqxx::result::field pqxx::result::tuple::at(const char f[]) const
 {
   const int fnum = m_Home->ColumnNumber(f);
   if (fnum == -1)
     throw invalid_argument(string("Unknown field '") + f + "'");
 
-  return Field(*this, fnum);
+  return field(*this, fnum);
 }
 
 
-pqxx::Result::Field pqxx::Result::Tuple::at(pqxx::Result::Tuple::size_type i) const
+pqxx::result::field pqxx::result::tuple::at(pqxx::result::tuple::size_type i) const
 {
   if ((i < 0) || (i >= size()))
     throw out_of_range("Invalid field number");
@@ -189,7 +193,7 @@ pqxx::Result::Field pqxx::Result::Tuple::at(pqxx::Result::Tuple::size_type i) co
 
 // const_iterator
 
-pqxx::Result::const_iterator pqxx::Result::const_iterator::operator++(int)
+pqxx::result::const_iterator pqxx::result::const_iterator::operator++(int)
 {
   const_iterator Old(*this);
   m_Index++;
@@ -197,7 +201,7 @@ pqxx::Result::const_iterator pqxx::Result::const_iterator::operator++(int)
 }
 
 
-pqxx::Result::const_iterator pqxx::Result::const_iterator::operator--(int)
+pqxx::result::const_iterator pqxx::result::const_iterator::operator--(int)
 {
   const_iterator Old(*this);
   m_Index--;
