@@ -4,11 +4,15 @@
  *	tablestream.cxx
  *
  *   DESCRIPTION
- *      implementation of the pqxx::TableStream class.
- *   pqxx::TableStream provides optimized batch access to a database table
+ *      implementation of the pqxx::tablestream class.
+ *   pqxx::tablestream provides optimized batch access to a database table
  *
  * Copyright (c) 2001-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
+ * See COPYING for copyright license.  If you did not receive a file called
+ * COPYING with this source code, please notify the distributor of this mistake,
+ * or contact the author.
+ *
  *-------------------------------------------------------------------------
  */
 #include "pqxx/tablestream.h"
@@ -17,7 +21,7 @@
 using namespace PGSTD;
 
 
-pqxx::TableStream::TableStream(Transaction_base &STrans, 
+pqxx::tablestream::tablestream(transaction_base &STrans, 
                                const string &SName, 
 			       const string &Null) :
   m_Trans(STrans),
@@ -28,7 +32,7 @@ pqxx::TableStream::TableStream(Transaction_base &STrans,
 }
 
 
-pqxx::TableStream::~TableStream()
+pqxx::tablestream::~tablestream()
 {
   m_Trans.UnregisterStream(this);
   m_Trans.EndCopy();
