@@ -3,6 +3,7 @@
 #include <pqxx/connection.h>
 #include <pqxx/nontransaction.h>
 #include <pqxx/result.h>
+#include <pqxx/transactor.h>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -12,20 +13,18 @@ using namespace pqxx;
 // a dummy transaction to gain nontransactional access, and perform a query.
 // This test uses a lazy connection.
 //
-// Usage: test34 [connect-string]
+// Usage: test034 [connect-string]
 //
 // Where connect-string is a set of connection options in Postgresql's
 // PQconnectdb() format, eg. "dbname=template1" to select from a database
 // called template1, or "host=foo.bar.net user=smith" to connect to a
 // backend running on host foo.bar.net, logging in as user smith.
 
-class ReadTables : public Transactor
+class ReadTables : public transactor<nontransaction>
 {
-  Result m_Result;
+  result m_Result;
 public:
-  typedef NonTransaction argument_type;
-
-  ReadTables() : Transactor("ReadTables") {}
+  ReadTables() : transactor<nontransaction>("ReadTables") {}
 
   void operator()(argument_type &T)
   {
@@ -34,7 +33,7 @@ public:
 
   void OnCommit()
   {
-    for (Result::const_iterator c = m_Result.begin(); c != m_Result.end(); ++c)
+    for (result::const_iterator c = m_Result.begin(); c != m_Result.end(); ++c)
     {
       string N;
       c[0].to(N);
@@ -49,7 +48,7 @@ int main(int, char *argv[])
 {
   try
   {
-    LazyConnection C(argv[1]);
+    lazyconnection C(argv[1]);
 
     // See if Deactivate() behaves...
     C.Deactivate();
