@@ -10,10 +10,10 @@ using namespace PGSTD;
 using namespace pqxx;
 
 
-// Test program for libpqxx.  Compare behaviour of a CachedResult to a regular
-// Result.
+// Test program for libpqxx.  Compare behaviour of a cachedresult to a regular
+// result.
 //
-// Usage: test40 [connect-string]
+// Usage: test040 [connect-string]
 //
 // Where connect-string is a set of connection options in Postgresql's
 // PQconnectdb() format, eg. "dbname=template1" to select from a database
@@ -24,22 +24,22 @@ int main(int, char *argv[])
   try
   {
     // Set up a connection to the backend
-    Connection C(argv[1]);
+    connection C(argv[1]);
 
     // Begin a transaction acting on our current connection
-    Transaction T(C, "test40");
+    transaction<serializable> T(C, "test40");
 
     const char Query[] = "SELECT * FROM events";
 
     // Perform a query on the database, storing result tuples in R
-    Result R( T.Exec(Query) );
+    result R( T.Exec(Query) );
 
     string LastReason;
 
     for (int BlockSize = 2; BlockSize <= R.size()+1; ++BlockSize)
     {
-      CachedResult CR(T, Query, "cachedresult", BlockSize);
-      const CachedResult::size_type CRS = CR.size();
+      cachedresult CR(T, Query, "cachedresult", BlockSize);
+      const cachedresult::size_type CRS = CR.size();
       if (CRS != R.size())
 	throw logic_error("BlockSize " + ToString(BlockSize) + ": "
 	                  "Expected " + ToString(R.size()) + " rows, "
@@ -50,7 +50,7 @@ int main(int, char *argv[])
 			  ToString(CR.size()) + ")");
 
       // Compare contents for CR with R
-      for (Result::size_type i = 0; i < R.size(); ++i)
+      for (result::size_type i = 0; i < R.size(); ++i)
       {
 	string A, B;
 	R.at(i).at(0).to(A);
@@ -64,7 +64,7 @@ int main(int, char *argv[])
 
       // CR was asked to compute its size explicitly.  With CR2, we let the
       // object find out its size by reading rows until they run out.
-      CachedResult CR2(T, Query, "cachedresult2", BlockSize);
+      cachedresult CR2(T, Query, "cachedresult2", BlockSize);
       CR2.at(CRS - 1);
       try 
       { 
