@@ -12,7 +12,7 @@ using namespace pqxx;
 
 // Test program for libpqxx.  Test Cursor with empty result set.
 //
-// Usage: test44 [connect-string]
+// Usage: test044 [connect-string]
 //
 // Where connect-string is a set of connection options in Postgresql's
 // PQconnectdb() format, eg. "dbname=template1" to select from a database
@@ -22,8 +22,8 @@ int main(int, char *argv[])
 {
   try
   {
-    Connection C(argv[1]);
-    Transaction T(C, "test44");
+    connection C(argv[1]);
+    transaction<serializable> T(C, "test44");
 
     // A query that will not return any data
     const char Query[] = "SELECT * FROM events WHERE year <> year";
