@@ -5,9 +5,9 @@
 using namespace PGSTD;
 using namespace pqxx;
 
-// Test program for libpqxx.  Test CachedResult's empty() and clear() methods.
+// Test program for libpqxx.  Test cachedresult's empty() and clear() methods.
 //
-// Usage: test47 [connect-string]
+// Usage: test047 [connect-string]
 //
 // Where connect-string is a set of connection options in Postgresql's
 // PQconnectdb() format, eg. "dbname=template1" to select from a database
@@ -17,32 +17,32 @@ int main(int, char *argv[])
 {
   try
   {
-    Connection C(argv[1]);
-    Transaction T(C, "test47");
+    connection C(argv[1]);
+    transaction<serializable> T(C, "test47");
 
     const char Full[] = "SELECT count(*) FROM pg_tables",
                Empty[] = "SELECT * from pg_tables WHERE 1 = 0";
 
     // Ask for size() first, then check empty()
-    CachedResult CR1(T, Full, "CR1");
+    cachedresult CR1(T, Full, "CR1");
     if (CR1.size() != 1) 
-      throw logic_error("CachedResult had size " + ToString(CR1.size()) + ", "
+      throw logic_error("cachedresult had size " + ToString(CR1.size()) + ", "
 	                "expected 1");
-    if (CR1.empty()) throw logic_error("CachedResult was empty!");
+    if (CR1.empty()) throw logic_error("cachedresult was empty!");
 
     // Try empty() method without asking for size()
-    CachedResult CR2(T, Full, "CR2");
-    if (CR2.empty()) throw logic_error("Unexpected empty CachedResult");
+    cachedresult CR2(T, Full, "CR2");
+    if (CR2.empty()) throw logic_error("Unexpected empty cachedresult");
 
     // Now try the same with an empty result
-    CachedResult CR3(T, Empty, "CR3");
-    if (!CR3.empty()) throw logic_error("CachedResult not empty as expected");
+    cachedresult CR3(T, Empty, "CR3");
+    if (!CR3.empty()) throw logic_error("cachedresult not empty as expected");
 
-    CachedResult CR4(T, Empty, "CR4");
+    cachedresult CR4(T, Empty, "CR4");
     if (CR4.size()) 
-      throw logic_error("CachedResult had size " + ToString(CR4.size()) + ", "
+      throw logic_error("cachedresult had size " + ToString(CR4.size()) + ", "
 	                "expected 0");
-    if (!CR4.empty()) throw logic_error("CachedResult was not empty!");
+    if (!CR4.empty()) throw logic_error("cachedresult was not empty!");
   }
   catch (const sql_error &e)
   {
