@@ -13,11 +13,11 @@ namespace
 const string Contents = "Large object test contents";
 
 
-class WriteLargeObject : public Transactor
+class WriteLargeObject : public transactor<>
 {
 public:
-  explicit WriteLargeObject(LargeObject &O) : 
-    Transactor("WriteLargeObject"),
+  explicit WriteLargeObject(largeobject &O) : 
+    transactor<>("WriteLargeObject"),
     m_Object(),
     m_ObjectOutput(O)
   {
@@ -25,21 +25,21 @@ public:
 
   void operator()(argument_type &T)
   {
-    LargeObjectAccess A(T);
+    largeobjectaccess A(T);
     cout << "Created large object #" << A.id() << endl;
-    m_Object = LargeObject(A);
+    m_Object = largeobject(A);
 
     A.write(Contents);
 
     char Buf[200];
-    const LargeObjectAccess::size_type Size = sizeof(Buf) - 1;
+    const largeobjectaccess::size_type Size = sizeof(Buf) - 1;
 
-    LargeObjectAccess::size_type Offset = A.seek(0, ios::beg);
+    largeobjectaccess::size_type Offset = A.seek(0, ios::beg);
     if (Offset != 0)
       throw logic_error("After seeking to start of large object, "
 	                "seek() returned " + ToString(Offset));
 
-    LargeObjectAccess::size_type Read = A.read(Buf, Size);
+    largeobjectaccess::size_type Read = A.read(Buf, Size);
     if (Read > Size)
       throw logic_error("Tried to read " + ToString(Size) + " bytes "
 	                "from large object, got " + ToString(Read));
@@ -89,15 +89,15 @@ public:
  }
 
 private:
-  LargeObject m_Object;
-  LargeObject &m_ObjectOutput;
+  largeobject m_Object;
+  largeobject &m_ObjectOutput;
 };
 
 
-class DeleteLargeObject : public Transactor
+class DeleteLargeObject : public transactor<>
 {
 public:
-  explicit DeleteLargeObject(LargeObject O) : m_Object(O) {}
+  explicit DeleteLargeObject(largeobject O) : m_Object(O) {}
 
   void operator()(argument_type &T)
   {
@@ -105,7 +105,7 @@ public:
   }
 
 private:
-  LargeObject m_Object;
+  largeobject m_Object;
 };
 
 
@@ -114,7 +114,7 @@ private:
 
 // Simple test program for libpqxx's Large Objects interface.
 //
-// Usage: test50 [connect-string]
+// Usage: test051 [connect-string]
 //
 // Where connect-string is a set of connection options in Postgresql's
 // PQconnectdb() format, eg. "dbname=template1" to select from a database
@@ -124,9 +124,9 @@ int main(int, char *argv[])
 {
   try
   {
-    Connection C(argv[1]);
+    connection C(argv[1]);
 
-    LargeObject Obj;
+    largeobject Obj;
 
     C.Perform(WriteLargeObject(Obj));
     C.Perform(DeleteLargeObject(Obj));
